==> 0.0.33.tar.gz: lib/receipt/receipt_section_text.dart <==
import 'package:rw_blue_print_pos/receipt/collection_style.dart';
import 'package:rw_blue_print_pos/receipt/receipt_column.dart';
import 'package:rw_blue_print_pos/receipt/receipt_image.dart';

import 'receipt_alignment.dart';
import 'receipt_line.dart';
import 'receipt_text.dart';
import 'receipt_text_left_right.dart';
import 'receipt_text_size_type.dart';
import 'receipt_text_style.dart';
import 'receipt_text_style_type.dart';

class ReceiptSectionText {
  ReceiptSectionText({
    this.numberColumn=1
});

  int numberColumn;
  String _data = '';

  /// Build a page from html, [CollectionStyle.all] is defined CSS inside html
  /// [_data] will collect all generated tag from model [ReceiptText],
  /// [ReceiptTextLeftRight] and [ReceiptLine]
  String get content {
    return '''
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RECEIPT</title>
</head>

${CollectionStyle.all}

<body>
  <div class="receipt">
    <div class="container">
      <!-- testing part -->
      
      $_data
      
    </div>
  </div>
</body>
</html>
    ''';
  }

  /// Handler tag of text (p or b) and put inside body html
  /// This will generate single line text left, center or right
  /// [text] value of text will print
  /// [alignment] to set alignment of text
  /// [style] define normal or bold
  /// [size] to set size of text small, medium, large or extra large
  void addText(
    String text, {
    ReceiptAlignment alignment = ReceiptAlignment.center,
    ReceiptTextStyleType style = ReceiptTextStyleType.normal,
    ReceiptTextSizeType size = ReceiptTextSizeType.medium,
  }) {
    final ReceiptText receiptText = ReceiptText(
      text,
      textStyle: ReceiptTextStyle(
        type: style,
        size: size,
      ),
      alignment: alignment,
    );

    _data += receiptText.html;
  }


String getItem (String text, ReceiptColumn column, ReceiptTextSizeType size,
    {ReceiptAlignment alignment = ReceiptAlignment.center, bool isMargin = false}){
  final ReceiptText receiptText = ReceiptText(
    text,
    textStyle:  ReceiptTextStyle(
      type: ReceiptTextStyleType.bold,
      size: size
    ),
    alignment: alignment,
    column: column,
    isMargin: isMargin
  );
  return receiptText.html;
}

  void addItemTexts(List<String> texts, { ReceiptTextSizeType size = ReceiptTextSizeType.extraLarge}) {
    String htmlContent= '';
    switch(numberColumn){
      case 1:
        for(int i = 0; i < texts.length; i++){
          htmlContent += '''
          <div class="$_row">
            ${getItem(texts[i], ReceiptColumn.one, size)}
          </div>
          ''';
        }
        break;
      case 2:
        final int mod = texts.length%2==0?0:1;

        for(int i = 0; i < texts.length; i=i+2){
          //final String rowClass = i+2 == texts.length+mod ? _rowLast: _row;
          htmlContent += '''
          <div class="$_row">
            ${getItem(texts[i], ReceiptColumn.two, size, alignment: ReceiptAlignment.left )}
          ''';

          if(i+1 < texts.length){
            htmlContent += '''                
                  ${getItem(texts[i+1], ReceiptColumn.two, size, isMargin: true, alignment: ReceiptAlignment.right)}
                </div>
                ''';
          } else{
            htmlContent += '''</div>''';
          }
        }
        break;
      case 3 :

        for (int i = 0; i < texts.length; i++) {
          if(i % 3 == 0)
            htmlContent += (i > 0) ? '''</div> <div class="$_row">''' : ''' <div class="$_row">''';
          htmlContent += getItem(texts[i], ReceiptColumn.three, size);
        }
        htmlContent+='''</div>''';
        break;
    }
    _data += htmlContent;
  }

  /// Handler tag of text (span or b) and put inside body html
  /// This will generate left right text with two value input from parameter
  /// [leftText] and [rightText]
  void addLeftRightText(
    String leftText,
    String rightText, {
    ReceiptTextStyleType leftStyle = ReceiptTextStyleType.normal,
    ReceiptTextStyleType rightStyle = ReceiptTextStyleType.normal,
    ReceiptTextSizeType leftSize = ReceiptTextSizeType.medium,
    ReceiptTextSizeType rightSize = ReceiptTextSizeType.medium,
  }) {
    final ReceiptTextLeftRight leftRightText = ReceiptTextLeftRight(
      leftText,
      rightText,
      leftTextStyle: ReceiptTextStyle(
        type: leftStyle,
        useSpan: true,
        size: leftSize,
      ),
      rightTextStyle: ReceiptTextStyle(
        type: leftStyle,
        useSpan: true,
        size: rightSize,
      ),
    );
    _data += leftRightText.html;
  }

  /// Add new line as empty or dashed line.
  /// [count] is how much line
  /// if [useDashed] true line will print as dashed line
  void addSpacer({int count = 1, bool useDashed = false}) {
    final ReceiptLine line = ReceiptLine(count: count, useDashed: useDashed);
    _data += line.html;
  }

  void addImage(
    String base64, {
    int width = 120,
    ReceiptAlignment alignment = ReceiptAlignment.center,
  }) {
    final ReceiptImage image = ReceiptImage(
      base64,
      width: width,
      alignment: alignment,
    );
    _data += image.html;
  }

  String get _row {
    return CollectionStyle.row;
  }

  String get _rowLast {
    return CollectionStyle.rowLast;
  }
}

==> 0.0.34.tar.gz: lib/receipt/receipt_section_text.dart <==
import 'package:rw_blue_print_pos/receipt/collection_style.dart';
import 'package:rw_blue_print_pos/receipt/receipt_column.dart';
import 'package:rw_blue_print_pos/receipt/receipt_image.dart';

import 'receipt_alignment.dart';
import 'receipt_line.dart';
import 'receipt_text.dart';
import 'receipt_text_left_right.dart';
import 'receipt_text_size_type.dart';
import 'receipt_text_style.dart';
import 'receipt_text_style_type.dart';

class ReceiptSectionText {
  ReceiptSectionText({
    this.numberColumn=1
});

  int numberColumn;
  String _data = '';

  /// Build a page from html, [CollectionStyle.all] is defined CSS inside html
  /// [_data] will collect all generated tag from model [ReceiptText],
  /// [ReceiptTextLeftRight] and [ReceiptLine]
  String get content {
    return '''
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RECEIPT</title>
</head>

${CollectionStyle.all}

<body>
  <div class="receipt">
    <div class="container">
      <!-- testing part -->
      
      $_data
      
    </div>
  </div>
</body>
</html>
    ''';
  }

  /// Handler tag of text (p or b) and put inside body html
  /// This will generate single line text left, center or right
  /// [text] value of text will print
  /// [alignment] to set alignment of text
  /// [style] define normal or bold
  /// [size] to set size of text small, medium, large or extra large
  void addText(
    String text, {
    ReceiptAlignment alignment = ReceiptAlignment.center,
    ReceiptTextStyleType style = ReceiptTextStyleType.normal,
    ReceiptTextSizeType size = ReceiptTextSizeType.medium,
  }) {
    final ReceiptText receiptText = ReceiptText(
      text,
      textStyle: ReceiptTextStyle(
        type: style,
        size: size,
      ),
      alignment: alignment,
    );

    _data += receiptText.html;
  }


String getItem (String text, String symbol, ReceiptColumn column, ReceiptTextSizeType size,
    {ReceiptAlignment alignment = ReceiptAlignment.center, bool isMargin = false}){
  final ReceiptText receiptText = ReceiptText(
    text,
    textStyle:  ReceiptTextStyle(
      type: ReceiptTextStyleType.bold,
      size: size
    ),
    alignment: alignment,
    column: column,
    isMargin: isMargin,
    symbol: symbol
  );
  return receiptText.html;
}

  void addItemTexts(String symbol, List<String> texts, { ReceiptTextSizeType size = ReceiptTextSizeType.extraLarge}) {
    String htmlContent= '';
    switch(numberColumn){
      case 1:
        for(int i = 0; i < texts.length; i++){
          htmlContent += '''
          <div class="$_row">
            ${getItem(texts[i], symbol, ReceiptColumn.one, size)}
          </div>
          ''';
        }
        break;
      case 2:
        final int mod = texts.length%2==0?0:1;

        for(int i = 0; i < texts.length; i=i+2){
          final String rowClass = i+2 == texts.length+mod ? _rowLast: _row;
          htmlContent += '''
          <div class="$rowClass">
            ${getItem(texts[i], symbol, ReceiptColumn.two, size, alignment: ReceiptAlignment.left )}
          ''';

          if(i+1 < texts.length){
            htmlContent += '''                
                  ${getItem(texts[i+1], symbol, ReceiptColumn.two, size, isMargin: true, alignment: ReceiptAlignment.right)}
                </div>
                ''';
          } else{
            htmlContent += '''</div>''';
          }
        }
        break;
      case 3 :

        for (int i = 0; i < texts.length; i++) {
          if(i % 3 == 0)
            htmlContent += (i > 0) ? '''</div> <div class="$_row">''' : ''' <div class="$_row">''';
          htmlContent += getItem(texts[i], symbol, ReceiptColumn.three, size);
        }
        htmlContent+='''</div>''';
        break;
    }
    _data += htmlContent;
  }

  /// Handler tag of text (span or b) and put inside body html
  /// This will generate left right text with two value input from parameter
  /// [leftText] and [rightText]
  void addLeftRightText(
    String leftText,
    String rightText, {
    ReceiptTextStyleType leftStyle = ReceiptTextStyleType.normal,
    ReceiptTextStyleType rightStyle = ReceiptTextStyleType.normal,
    ReceiptTextSizeType leftSize = ReceiptTextSizeType.medium,
    ReceiptTextSizeType rightSize = ReceiptTextSizeType.medium,
  }) {
    final ReceiptTextLeftRight leftRightText = ReceiptTextLeftRight(
      leftText,
      rightText,
      leftTextStyle: ReceiptTextStyle(
        type: leftStyle,
        useSpan: true,
        size: leftSize,
      ),
      rightTextStyle: ReceiptTextStyle(
        type: leftStyle,
        useSpan: true,
        size: rightSize,
      ),
    );
    _data += leftRightText.html;
  }

  /// Add new line as empty or dashed line.
  /// [count] is how much line
  /// if [useDashed] true line will print as dashed line
  void addSpacer({int count = 1, bool useDashed = false}) {
    final ReceiptLine line = ReceiptLine(count: count, useDashed: useDashed);
    _data += line.html;
  }

  void addImage(
    String base64, {
    int width = 120,
    ReceiptAlignment alignment = ReceiptAlignment.center,
  }) {
    final ReceiptImage image = ReceiptImage(
      base64,
      width: width,
      alignment: alignment,
    );
    _data += image.html;
  }

  String get _row {
    return CollectionStyle.row;
  }

  String get _rowLast {
    return CollectionStyle.rowLast;
  }
}
